#!/usr/bin/python
#-*- coding: utf-8 -*-

import RPi.GPIO as GPIO
import time
import commands
import json
import urllib2

PIN_PREV_BTN = 7
PIN_PLAY_BTN = 11
PIN_NEXT_BTN = 13
PIN_STOP_BTN = 32
PIN_VOL_UP_BTN = 33
PIN_VOL_DW_BTN = 31

TOKYO  = '130010'
SAPORO = '016010'
SENDAI = '040010'
NAGOYA = '230010'
OSAKA  = '270000'
NAHA  = '471010'

JSON_URL = 'http://weather.livedoor.com/forecast/webservice/json/v1?city=' #API URL
P_CMD1 = 'aws polly synthesize-speech --output-format mp3 --voice-id Mizuki --text %"'
P_CMD2 = '%" polly.mp3'

class Player(object):
    def __init__(self):
        pass

    def talk(self,city):

        try:
            r = urllib2.urlopen(JSON_URL + city)
            obj = json.loads( unicode(r.read()) )
            str = obj['title']+obj['description']['text']
            print str
            
#            f = open('polly.txt', 'w')
#            f.write(str.encode('utf-8'))
#            f.close() # ファイルを閉じる

            snd_dat = P_CMD1 + str.encode('utf-8') + P_CMD2
            retval = commands.getoutput(snd_dat) 
            print retval
            commands.getoutput('mpg123 -r 48000 --stereo polly.mp3')

        finally:
            r.close()

        return

    def prev(self):
        self.talk(SAPORO)

    def play(self):
        self.talk(SENDAI)

    def next(self):
        self.talk(TOKYO)

    def stop(self):
        self.talk(NAGOYA)

    def voldw(self):
        self.talk(OSAKA)

    def volup(self):
        self.talk(NAHA)

class Button(object):
    def __init__(self, pin, func):
        self.pin = pin
        self.old_state = 1
        self.func = func
        self.up_timer = 0
        GPIO.setup(pin, GPIO.IN, pull_up_down=GPIO.PUD_UP)

    def update(self):
        curr_state = GPIO.input(self.pin)
        if self.old_state is 1 and curr_state is 0:
            self.func()
        self.old_state = curr_state

def main():
    GPIO.setmode(GPIO.BOARD)
    GPIO.setwarnings(False)

    player = Player()

    prev_btn = Button(PIN_PREV_BTN, lambda:  player.prev())
    play_btn = Button(PIN_PLAY_BTN, lambda:  player.play())
    next_btn = Button(PIN_NEXT_BTN, lambda:  player.next())
    stop_btn = Button(PIN_STOP_BTN, lambda:  player.stop())
    voldw_btn = Button(PIN_VOL_DW_BTN, lambda:  player.voldw())
    volup_btn = Button(PIN_VOL_UP_BTN, lambda:  player.volup())

    while True:
        prev_btn.update()
        play_btn.update()
        next_btn.update()
        stop_btn.update()
        voldw_btn.update()
        volup_btn.update()
        time.sleep(0.05)

if __name__ == '__main__':
        main()
        GPIO.cleanup()
